@@ -63,7 +63,6 @@ using KMail::MailServiceImpl;
 
 #include <MailCommon/FolderSettings>
 
-#include <KMessageBox>
 #include <KNotification>
 
 #include "kmail_debug.h"
@@ -579,7 +578,7 @@ void KMKernel::raise()
                          QDBusConnection::sessionBus());
     QDBusReply<int> reply;
     if (!iface.isValid() || !(reply = iface.call(QStringLiteral("newInstance"))).isValid()) {
-        QDBusError err = iface.lastError();
+        const QDBusError err = iface.lastError();
         qCritical() << "Communication problem with KMail. "
                     << "Error message was:" << err.name() << ": \"" << err.message() << "\"";
     }
@@ -877,7 +876,7 @@ void KMKernel::recoverDeadLetters()
         qCDebug(KMAIL_LOG) << "Opening autosave file:" << file.absoluteFilePath();
         QFile autoSaveFile(file.absoluteFilePath());
         if (autoSaveFile.open(QIODevice::ReadOnly)) {
-            const KMime::Message::Ptr autoSaveMessage(new KMime::Message());
+            const std::shared_ptr<KMime::Message> autoSaveMessage(new KMime::Message());
             const QByteArray msgData = autoSaveFile.readAll();
             autoSaveMessage->setContent(msgData);
             autoSaveMessage->parse();
@@ -1291,7 +1290,7 @@ void KMKernel::selectCollectionFromId(Akonadi::Collection::Id id)
         return;
     }
 
-    Akonadi::Collection colFolder = CommonKernel->collectionFromId(id);
+    const Akonadi::Collection colFolder = CommonKernel->collectionFromId(id);
 
     if (colFolder.isValid()) {
         widget->slotSelectCollectionFolder(colFolder);
@@ -1432,10 +1431,8 @@ MessageComposer::MessageSender *KMKernel::msgSender()
     return the_msgSender;
 }
 
-void KMKernel::transportRemoved(int id, const QString &name)
+void KMKernel::transportRemoved([[maybe_unused]] int id, const QString &name)
 {
-    Q_UNUSED(id)
-
     // reset all identities using the deleted transport
     QStringList changedIdents;
     KIdentityManagementCore::IdentityManager *im = identityManager();
@@ -1463,10 +1460,8 @@ void KMKernel::transportRemoved(int id, const QString &name)
     }
 }
 
-void KMKernel::transportRenamed(int id, const QString &oldName, const QString &newName)
+void KMKernel::transportRenamed([[maybe_unused]] int id, const QString &oldName, const QString &newName)
 {
-    Q_UNUSED(id)
-
     QStringList changedIdents;
     KIdentityManagementCore::IdentityManager *im = identityManager();
     KIdentityManagementCore::IdentityManager::Iterator end = im->modifyEnd();
@@ -1912,10 +1907,8 @@ void KMKernel::setShuttingDown(bool flag)
     the_shuttingDown = flag;
 }
 
-void KMKernel::expunge(Akonadi::Collection::Id col, bool sync)
+void KMKernel::expunge([[maybe_unused]] Akonadi::Collection::Id col, [[maybe_unused]] bool sync)
 {
-    Q_UNUSED(col)
-    Q_UNUSED(sync)
 }
 
 #if KMAIL_WITH_KUSERFEEDBACK
