@@ -14,7 +14,7 @@
 // widgets like a toolbar.
 
 #include "kmreadermainwin.h"
-
+#include "config-kmail.h"
 #include "historyclosedreader/historyclosedreadermanager.h"
 #include "job/composenewmessagejob.h"
 #include "kmmainwidget.h"
@@ -84,6 +84,15 @@ KMReaderMainWin::KMReaderMainWin(KMime::Content *aMsgPart, MessageViewer::Viewer
     mReaderWin->setMsgPart(aMsgPart);
 }
 
+KMReaderMainWin::KMReaderMainWin(const std::shared_ptr<KMime::Content> &aMsgPart,
+                                 MessageViewer::Viewer::DisplayFormatMessage format,
+                                 const QString &encoding,
+                                 const QString &name)
+    : KMReaderMainWin(aMsgPart.get(), format, encoding, name)
+{
+    m_msgPart = aMsgPart;
+}
+
 void KMReaderMainWin::initKMReaderMainWin()
 {
     setCentralWidget(mReaderWin);
@@ -95,6 +104,7 @@ void KMReaderMainWin::initKMReaderMainWin()
     setAutoSaveSettings(stateConfigGroup(), true);
 
     mZoomLabelIndicator = new ZoomLabelWidget(statusBar());
+    connect(mZoomLabelIndicator, &ZoomLabelWidget::changeZoom, mReaderWin, &KMReaderWin::zoomChangeRequested);
     statusBar()->addPermanentWidget(mZoomLabelIndicator);
     setZoomChanged(mReaderWin->viewer()->webViewZoomFactor());
     statusBar()->addPermanentWidget(mReaderWin->viewer()->dkimWidgetInfo());
@@ -118,9 +128,9 @@ KMReaderMainWin::~KMReaderMainWin()
     if (mMsg.isValid()) {
         HistoryClosedReaderInfo info;
         info.setItem(mMsg.id());
-        KMime::Message::Ptr message = MessageComposer::Util::message(mMsg);
+        std::shared_ptr<KMime::Message> message = MessageComposer::Util::message(mMsg);
         if (message) {
-            if (auto subject = message->subject(false)) {
+            if (auto subject = message->subject(KMime::CreatePolicy::DontCreate)) {
                 info.setSubject(subject->asUnicodeString());
             }
         }
@@ -155,10 +165,10 @@ void KMReaderMainWin::showMessage(const QString &encoding, const Akonadi::Item &
     mParentCollection = parentCollection;
     mReaderWin->setOverrideEncoding(encoding);
     mReaderWin->setMessage(msg, MimeTreeParser::Force);
-    KMime::Message::Ptr message = MessageComposer::Util::message(msg);
+    std::shared_ptr<KMime::Message> message = MessageComposer::Util::message(msg);
     QString caption;
     if (message) {
-        if (auto subject = message->subject(false)) {
+        if (auto subject = message->subject(KMime::CreatePolicy::DontCreate)) {
             caption = subject->asUnicodeString();
         }
     }
@@ -214,7 +224,7 @@ void KMReaderMainWin::showPreviousMessage()
     updateButtons();
 }
 
-void KMReaderMainWin::showMessage(const QString &encoding, const QList<KMime::Message::Ptr> &message)
+void KMReaderMainWin::showMessage(const QString &encoding, const QList<std::shared_ptr<KMime::Message>> &message)
 {
     if (message.isEmpty()) {
         return;
@@ -229,10 +239,10 @@ void KMReaderMainWin::showMessage(const QString &encoding, const QList<KMime::Me
     updateButtons();
 }
 
-void KMReaderMainWin::initializeMessage(const KMime::Message::Ptr &message)
+void KMReaderMainWin::initializeMessage(const std::shared_ptr<KMime::Message> &message)
 {
     Akonadi::Item item;
-    item.setPayload<KMime::Message::Ptr>(message);
+    item.setPayload<std::shared_ptr<KMime::Message>>(message);
     Akonadi::MessageFlags::copyMessageFlags(*message, item);
     item.setMimeType(KMime::Message::mimeType());
 
@@ -240,7 +250,7 @@ void KMReaderMainWin::initializeMessage(const KMime::Message::Ptr &message)
     mMsgActions->setCurrentMessage(item);
 
     mReaderWin->setMessage(message);
-    if (auto subject = message->subject(false)) {
+    if (auto subject = message->subject(KMime::CreatePolicy::DontCreate)) {
         setCaption(subject->asUnicodeString());
     }
     mTrashAction->setEnabled(false);
@@ -248,12 +258,12 @@ void KMReaderMainWin::initializeMessage(const KMime::Message::Ptr &message)
     updateActions();
 }
 
-void KMReaderMainWin::showMessage(const QString &encoding, const KMime::Message::Ptr &message)
+void KMReaderMainWin::showMessage(const QString &encoding, const std::shared_ptr<KMime::Message> &message)
 {
     if (!message) {
         return;
     }
-    const QList<KMime::Message::Ptr> lst{message};
+    const QList<std::shared_ptr<KMime::Message>> lst{message};
     showMessage(encoding, lst);
 }
 
@@ -332,7 +342,7 @@ void KMReaderMainWin::slotTrashMessage()
 
 void KMReaderMainWin::slotForwardInlineMsg()
 {
-    if (!mReaderWin->messageItem().hasPayload<KMime::Message::Ptr>()) {
+    if (!mReaderWin->messageItem().hasPayload<std::shared_ptr<KMime::Message>>()) {
         return;
     }
     KMCommand *command = nullptr;
@@ -353,7 +363,7 @@ void KMReaderMainWin::slotForwardInlineMsg()
 
 void KMReaderMainWin::slotForwardAttachedMessage()
 {
-    if (!mReaderWin->messageItem().hasPayload<KMime::Message::Ptr>()) {
+    if (!mReaderWin->messageItem().hasPayload<std::shared_ptr<KMime::Message>>()) {
         return;
     }
     KMCommand *command = nullptr;
@@ -394,7 +404,7 @@ void KMReaderMainWin::slotNewMessageToRecipients()
 void KMReaderMainWin::slotRedirectMessage()
 {
     const Akonadi::Item currentItem = mReaderWin->messageItem();
-    if (!currentItem.hasPayload<KMime::Message::Ptr>()) {
+    if (!currentItem.hasPayload<std::shared_ptr<KMime::Message>>()) {
         return;
     }
     auto command = new KMRedirectCommand(this, currentItem);
@@ -405,7 +415,7 @@ void KMReaderMainWin::slotRedirectMessage()
 void KMReaderMainWin::slotCustomReplyToMsg(const QString &tmpl)
 {
     const Akonadi::Item currentItem = mReaderWin->messageItem();
-    if (!currentItem.hasPayload<KMime::Message::Ptr>()) {
+    if (!currentItem.hasPayload<std::shared_ptr<KMime::Message>>()) {
         return;
     }
     auto command = new KMReplyCommand(this, currentItem, MessageComposer::ReplySmart, mReaderWin->copyText(), false, tmpl);
@@ -417,7 +427,7 @@ void KMReaderMainWin::slotCustomReplyToMsg(const QString &tmpl)
 void KMReaderMainWin::slotCustomReplyAllToMsg(const QString &tmpl)
 {
     const Akonadi::Item currentItem = mReaderWin->messageItem();
-    if (!currentItem.hasPayload<KMime::Message::Ptr>()) {
+    if (!currentItem.hasPayload<std::shared_ptr<KMime::Message>>()) {
         return;
     }
     auto command = new KMReplyCommand(this, currentItem, MessageComposer::ReplyAll, mReaderWin->copyText(), false, tmpl);
@@ -430,7 +440,7 @@ void KMReaderMainWin::slotCustomReplyAllToMsg(const QString &tmpl)
 void KMReaderMainWin::slotCustomForwardMsg(const QString &tmpl)
 {
     const Akonadi::Item currentItem = mReaderWin->messageItem();
-    if (!currentItem.hasPayload<KMime::Message::Ptr>()) {
+    if (!currentItem.hasPayload<std::shared_ptr<KMime::Message>>()) {
         return;
     }
     auto command = new KMForwardCommand(this, currentItem, 0, tmpl, mReaderWin->copyText());
@@ -639,7 +649,7 @@ void KMReaderMainWin::slotMessagePopup(const Akonadi::Item &aMsg, const WebEngin
         job->setProperty("imageUrl", imageUrl);
         job->setProperty("url", aUrl);
         job->setProperty("webhitresult", QVariant::fromValue(result));
-        connect(job, &Akonadi::ItemCopyJob::result, this, &KMReaderMainWin::slotContactSearchJobForMessagePopupDone);
+        connect(job, &Akonadi::ContactSearchJob::result, this, &KMReaderMainWin::slotContactSearchJobForMessagePopupDone);
     } else {
         showMessagePopup(mMsg, aUrl, imageUrl, aPoint, false, false, result);
     }
@@ -679,7 +689,7 @@ void KMReaderMainWin::showMessagePopup(const Akonadi::Item &msg,
 
     bool urlMenuAdded = false;
     bool copyAdded = false;
-    const bool messageHasPayload = msg.hasPayload<KMime::Message::Ptr>();
+    const bool messageHasPayload = msg.hasPayload<std::shared_ptr<KMime::Message>>();
     if (!url.isEmpty()) {
         if (url.scheme() == "mailto"_L1) {
             // popup on a mailto URL
@@ -747,7 +757,7 @@ void KMReaderMainWin::showMessagePopup(const Akonadi::Item &msg,
         mMsgActions->addWebShortcutsMenu(menu, selectedText);
         menu->addSeparator();
         menu->addActions(mReaderWin->viewerPluginActionList(MessageViewer::ViewerPluginInterface::NeedSelection));
-#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_TEXT_TO_SPEECH_SUPPORT
         menu->addSeparator();
         menu->addAction(mReaderWin->speakTextAction());
 #endif
